@@ -27,11 +27,11 @@ plugin = defaultPlugin { parsedResultAction = parsedPlugin
                        , interfaceLoadAction = interfaceLoadPlugin'
                        }
 
-parsedPlugin :: [CommandLineOption] -> ModSummary -> HsParsedModule
-                  -> Hsc HsParsedModule
-parsedPlugin [name, "parse"] _ pm
-  = return $ pm { hpm_module = removeParsedBinding name (hpm_module pm) }
-parsedPlugin _ _ pm = return pm
+parsedPlugin :: [CommandLineOption] -> ModSummary
+             -> ParsedResult -> Hsc ParsedResult
+parsedPlugin [name, "parse"] _ (ParsedResult pm msgs)
+  = return (ParsedResult pm { hpm_module = removeParsedBinding name (hpm_module pm) } msgs)
+parsedPlugin _ _ parsed = return parsed
 
 removeParsedBinding :: String -> Located HsModule
                          -> Located HsModule
@@ -48,13 +48,13 @@ typecheckPlugin [name, "typecheck"] _ tc
                 }
   where notNamedAs name (L _ FunBind { fun_id = L _ fid })
           = occNameString (getOccName fid) /= name
-        notNamedAs name (L _ AbsBinds { abs_binds = bnds })
+        notNamedAs name (L _ (XHsBindsLR (AbsBinds { abs_binds = bnds })))
           = all (notNamedAs name) bnds
         notNamedAs _ (L _ b) = True
 typecheckPlugin _ _ tc = return tc
 
 metaPlugin' :: [CommandLineOption] -> LHsExpr GhcTc -> TcM (LHsExpr GhcTc)
-metaPlugin' [name, "meta"] (L l (HsPar x (L _ (XExpr (WrapExpr (HsWrap w (HsApp noExt (L _ (HsVar _ (L _ id))) e)))))))
+metaPlugin' [name, "meta"] (L l (XExpr (WrapExpr (HsWrap w (HsPar _ _ (L _ (HsApp noExt (L _ (HsVar _ (L _ id))) e)) _ )))))
   | occNameString (getOccName id) == name
   = return (L l (XExpr (WrapExpr (HsWrap w (unLoc e)))))
 -- The test should always match this first case. If the desugaring changes
