@@ -4,6 +4,14 @@ foo = f >>= \case
         Just h -> loadTestDB (h ++ "/.testdb")
         Nothing -> fmap S.Right initTestDB
 
+foo = f >>= \cases
+        x (Just h) -> loadTestDB (h ++ "/.testdb")
+        _ Nothing -> fmap S.Right initTestDB
+
+foo = f >>= \cases
+        | a -> loadTestDB (h ++ "/.testdb")
+        | b -> fmap S.Right initTestDB
+
 {-| Is the alarm set - i.e. will it go off at some point in the future even if
    `setAlarm` is not called? -}
 isAlarmSetSTM :: AlarmClock -> STM Bool
